# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ExecutionStateEnum


class Rollback(BaseModel):
    device_rollback: Optional["RollbackDeviceRollback"] = Field(alias="deviceRollback")


class RollbackDeviceRollback(BaseModel):
    execution: Optional["RollbackDeviceRollbackExecution"]


class RollbackDeviceRollbackExecution(BaseModel):
    id: str
    task_id: Optional[str] = Field(alias="taskId")
    state: Optional[ExecutionStateEnum]


Rollback.model_rebuild()
RollbackDeviceRollback.model_rebuild()
