# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class RoleDeviceGroupUpsert(BaseModel):
    role_device_group_upsert: Optional["RoleDeviceGroupUpsertRoleDeviceGroupUpsert"] = (
        Field(alias="roleDeviceGroupUpsert")
    )


class RoleDeviceGroupUpsertRoleDeviceGroupUpsert(BaseModel):
    role_device_group: Optional[
        "RoleDeviceGroupUpsertRoleDeviceGroupUpsertRoleDeviceGroup"
    ] = Field(alias="roleDeviceGroup")


class RoleDeviceGroupUpsertRoleDeviceGroupUpsertRoleDeviceGroup(BaseModel):
    id: str
    permission_flags: Optional[List[Optional[str]]] = Field(alias="permissionFlags")


RoleDeviceGroupUpsert.model_rebuild()
RoleDeviceGroupUpsertRoleDeviceGroupUpsert.model_rebuild()
