# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ExecutionStateEnum


class SingleDiscovery(BaseModel):
    discovery: Optional["SingleDiscoveryDiscovery"]


class SingleDiscoveryDiscovery(BaseModel):
    execution: Optional["SingleDiscoveryDiscoveryExecution"]


class SingleDiscoveryDiscoveryExecution(BaseModel):
    id: str
    task_id: Optional[str] = Field(alias="taskId")
    state: Optional[ExecutionStateEnum]


SingleDiscovery.model_rebuild()
SingleDiscoveryDiscovery.model_rebuild()
