# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class AddApiKey(BaseModel):
    static_api_key_create: Optional["AddApiKeyStaticApiKeyCreate"] = Field(
        alias="staticApiKeyCreate"
    )


class AddApiKeyStaticApiKeyCreate(BaseModel):
    app: Optional[str]
    access_token: Optional[str] = Field(alias="accessToken")


AddApiKey.model_rebuild()
