# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ExecutionStateEnum


class Discovery(BaseModel):
    execute: Optional["DiscoveryExecute"]


class DiscoveryExecute(BaseModel):
    execution: Optional["DiscoveryExecuteExecution"]


class DiscoveryExecuteExecution(BaseModel):
    id: str
    task_id: Optional[str] = Field(alias="taskId")
    state: Optional[ExecutionStateEnum]


Discovery.model_rebuild()
DiscoveryExecute.model_rebuild()
