# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class AddUsersToRole(BaseModel):
    role_add_users: Optional["AddUsersToRoleRoleAddUsers"] = Field(alias="roleAddUsers")


class AddUsersToRoleRoleAddUsers(BaseModel):
    role: Optional["AddUsersToRoleRoleAddUsersRole"]


class AddUsersToRoleRoleAddUsersRole(BaseModel):
    id: str
    name: Optional[str]
    users: Optional[List[Optional["AddUsersToRoleRoleAddUsersRoleUsers"]]]


class AddUsersToRoleRoleAddUsersRoleUsers(BaseModel):
    id: str
    username: Optional[str]


AddUsersToRole.model_rebuild()
AddUsersToRoleRoleAddUsers.model_rebuild()
AddUsersToRoleRoleAddUsersRole.model_rebuild()
