# Generated by ariadne-codegen

from .abort_execution import (
    AbortExecution,
    AbortExecutionAbortExecution,
    AbortExecutionAbortExecutionExecutions,
    AbortExecutionAbortExecutionExecutionsNeopsTask,
)
from .add_api_key import AddApiKey, AddApiKeyStaticApiKeyCreate
from .add_role import (
    AddRole,
    AddRoleRoleUpsert,
    AddRoleRoleUpsertRole,
    AddRoleRoleUpsertRoleUsers,
)
from .add_role_device_group import (
    AddRoleDeviceGroup,
    AddRoleDeviceGroupRoleDeviceGroupUpsert,
    AddRoleDeviceGroupRoleDeviceGroupUpsertRoleDeviceGroup,
    AddRoleDeviceGroupRoleDeviceGroupUpsertRoleDeviceGroupDeviceGroup,
    AddRoleDeviceGroupRoleDeviceGroupUpsertRoleDeviceGroupDeviceGroupDevices,
    AddRoleDeviceGroupRoleDeviceGroupUpsertRoleDeviceGroupRole,
    AddRoleDeviceGroupRoleDeviceGroupUpsertRoleDeviceGroupRoleUsers,
)
from .add_role_neops_task import (
    AddRoleNeopsTask,
    AddRoleNeopsTaskRoleNeopsTaskUpsert,
    AddRoleNeopsTaskRoleNeopsTaskUpsertRoleNeopsTask,
    AddRoleNeopsTaskRoleNeopsTaskUpsertRoleNeopsTaskNeopsTask,
    AddRoleNeopsTaskRoleNeopsTaskUpsertRoleNeopsTaskRole,
    AddRoleNeopsTaskRoleNeopsTaskUpsertRoleNeopsTaskRoleUsers,
)
from .add_user import AddUser, AddUserLocalUserCreate, AddUserLocalUserCreateLocalUser
from .add_users_to_role import (
    AddUsersToRole,
    AddUsersToRoleRoleAddUsers,
    AddUsersToRoleRoleAddUsersRole,
    AddUsersToRoleRoleAddUsersRoleUsers,
)
from .archive_or_delete_task import (
    ArchiveOrDeleteTask,
    ArchiveOrDeleteTaskNeopsTaskDelete,
    ArchiveOrDeleteTaskNeopsTaskDeleteNeopsTask,
)
from .async_base_client import AsyncBaseClient
from .autocomplete_fields import AutocompleteFields
from .base_model import BaseModel, Upload
from .client import Client
from .client_aggregation import (
    ClientAggregation,
    ClientAggregationClientAggregation,
    ClientAggregationClientAggregationResults,
)
from .clients import (
    Clients,
    ClientsClientsElastic,
    ClientsClientsElasticResults,
    ClientsClientsElasticResultsInterface,
    ClientsClientsElasticResultsInterfaceDevice,
    ClientsClientsElasticResultsLocation,
)
from .cron_execution_type import (
    CronExecutionType,
    CronExecutionTypeCronjobExecutionTypes,
    CronExecutionTypeCronjobExecutionTypesResults,
)
from .device_aggregation import (
    DeviceAggregation,
    DeviceAggregationDeviceAggregation,
    DeviceAggregationDeviceAggregationResults,
)
from .device_group_elastic import (
    DeviceGroupElastic,
    DeviceGroupElasticGroupsElastic,
    DeviceGroupElasticGroupsElasticResults,
    DeviceGroupElasticGroupsElasticResultsLocation,
)
from .device_group_upsert import (
    DeviceGroupUpsert,
    DeviceGroupUpsertDeviceGroupUpsert,
    DeviceGroupUpsertDeviceGroupUpsertDeviceGroup,
    DeviceGroupUpsertDeviceGroupUpsertDeviceGroupDevices,
)
from .device_upsert import (
    DeviceUpsert,
    DeviceUpsertDeviceUpsert,
    DeviceUpsertDeviceUpsertDevice,
    DeviceUpsertDeviceUpsertDeviceGroups,
    DeviceUpsertDeviceUpsertDevicePlatform,
)
from .devices import (
    Devices,
    DevicesDevicesElastic,
    DevicesDevicesElasticResults,
    DevicesDevicesElasticResultsGroups,
    DevicesDevicesElasticResultsPlatform,
)
from .discovery import Discovery, DiscoveryExecute, DiscoveryExecuteExecution
from .enums import (
    AggregationsType,
    ChartType,
    CheckResultEnum,
    ConnectionStateEnum,
    CronExecuteTypeEnum,
    CronJobExecuteTypeEnum,
    DeviceExecutionStateEnum,
    EntityType,
    ExecutionResultStateEnum,
    ExecutionStateEnum,
    ExecutionTypeEnum,
    IndexesEnum,
    InterfaceStateEnum,
    NeopsTask_ProviderTypeEnum,
    NeopsTask_RunOnEnum,
    NeopsTask_RunOnStrictEnum,
    NeopsTask_ValidityStateEnum,
    NeopsTaskCronJobExecuteTypeEnum,
    OutputSchemaTypeEnum,
    ProviderSchemaEnum,
    ProviderTypeEnum,
    RegexTypeEnum,
    RunOnEnum,
)
from .exceptions import (
    GraphQLClientError,
    GraphQLClientGraphQLError,
    GraphQLClientGraphQLMultiError,
    GraphQLClientHttpError,
    GraphQLClientInvalidResponseError,
)
from .execute_neops_task import (
    ExecuteNeopsTask,
    ExecuteNeopsTaskExecuteNeopsTask,
    ExecuteNeopsTaskExecuteNeopsTaskExecutions,
    ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecution,
    ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecutionDevice,
    ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecutionDevicePlatform,
    ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecutionExecution,
    ExecuteNeopsTaskExecuteNeopsTaskExecutionsNeopsTask,
    ExecuteNeopsTaskExecuteNeopsTaskExecutionsNeopsTaskProvider,
)
from .execution import (
    Execution,
    ExecutionExecutions,
    ExecutionExecutionsResults,
    ExecutionExecutionsResultsDeviceExecution,
    ExecutionExecutionsResultsDeviceExecutionDevice,
    ExecutionExecutionsResultsDeviceExecutionDevicePlatform,
    ExecutionExecutionsResultsExecutionResults,
    ExecutionExecutionsResultsExecutionResultsClientexecutionresult,
    ExecutionExecutionsResultsExecutionResultsClientexecutionresultClient,
    ExecutionExecutionsResultsExecutionResultsDeviceexecutionresult,
    ExecutionExecutionsResultsExecutionResultsDeviceexecutionresultDevice,
    ExecutionExecutionsResultsExecutionResultsDevicegroupexecutionresult,
    ExecutionExecutionsResultsExecutionResultsDevicegroupexecutionresultGroup,
    ExecutionExecutionsResultsExecutionResultsInterfaceexecutionresult,
    ExecutionExecutionsResultsExecutionResultsInterfaceexecutionresultInterface,
    ExecutionExecutionsResultsNeopsTask,
    ExecutionExecutionsResultsNeopsTaskProvider,
    ExecutionExecutionsResultsProcess,
)
from .execution_subscription import (
    ExecutionSubscription,
    ExecutionSubscriptionExecutionSubscription,
    ExecutionSubscriptionExecutionSubscriptionExecution,
    ExecutionSubscriptionExecutionSubscriptionExecutionNeopsTask,
    ExecutionSubscriptionExecutionSubscriptionExecutionNeopsTaskProvider,
    ExecutionSubscriptionExecutionSubscriptionExecutionProcess,
)
from .executions_detail import (
    ExecutionsDetail,
    ExecutionsDetailExecutions,
    ExecutionsDetailExecutionsResults,
    ExecutionsDetailExecutionsResultsExecutionResults,
    ExecutionsDetailExecutionsResultsExecutionResultsClientexecutionresult,
    ExecutionsDetailExecutionsResultsExecutionResultsClientexecutionresultClient,
    ExecutionsDetailExecutionsResultsExecutionResultsDeviceexecutionresult,
    ExecutionsDetailExecutionsResultsExecutionResultsDeviceexecutionresultDevice,
    ExecutionsDetailExecutionsResultsExecutionResultsDevicegroupexecutionresult,
    ExecutionsDetailExecutionsResultsExecutionResultsDevicegroupexecutionresultGroup,
    ExecutionsDetailExecutionsResultsExecutionResultsInterfaceexecutionresult,
    ExecutionsDetailExecutionsResultsExecutionResultsInterfaceexecutionresultInterface,
    ExecutionsDetailExecutionsResultsNeopsTask,
    ExecutionsDetailExecutionsResultsNeopsTaskProvider,
    ExecutionsDetailExecutionsResultsProcess,
    ExecutionsDetailExecutionsResultsUser,
)
from .executions_elastic import (
    ExecutionsElastic,
    ExecutionsElasticExecutionsElastic,
    ExecutionsElasticExecutionsElasticResults,
    ExecutionsElasticExecutionsElasticResultsNeopsTask,
    ExecutionsElasticExecutionsElasticResultsNeopsTaskProvider,
    ExecutionsElasticExecutionsElasticResultsProcess,
    ExecutionsElasticExecutionsElasticResultsUser,
)
from .executions_simple import (
    ExecutionsSimple,
    ExecutionsSimpleExecutions,
    ExecutionsSimpleExecutionsResults,
    ExecutionsSimpleExecutionsResultsNeopsTask,
    ExecutionsSimpleExecutionsResultsNeopsTaskProvider,
    ExecutionsSimpleExecutionsResultsProcess,
    ExecutionsSimpleExecutionsResultsUser,
)
from .get_role import GetRole, GetRoleRole, GetRoleRoleResults
from .group_aggregation import (
    GroupAggregation,
    GroupAggregationGroupAggregation,
    GroupAggregationGroupAggregationResults,
)
from .interface_aggregation import (
    InterfaceAggregation,
    InterfaceAggregationInterfaceAggregation,
    InterfaceAggregationInterfaceAggregationResults,
)
from .interfaces import (
    Interfaces,
    InterfacesInterfacesElastic,
    InterfacesInterfacesElasticResults,
    InterfacesInterfacesElasticResultsDevice,
    InterfacesInterfacesElasticResultsInterface,
)
from .json_form import (
    JsonForm,
    JsonFormJsonForm,
    JsonFormJsonFormClients,
    JsonFormJsonFormDevices,
    JsonFormJsonFormGroups,
    JsonFormJsonFormInterfaces,
    JsonFormJsonFormInterfacesDevice,
)
from .location_upsert import (
    LocationUpsert,
    LocationUpsertLocationUpsert,
    LocationUpsertLocationUpsertLocation,
    LocationUpsertLocationUpsertLocationDevices,
)
from .login import Login, LoginLogin, LoginLoginUser
from .neops_provider import (
    NeopsProvider,
    NeopsProviderNeopsTaskProvider,
    NeopsProviderNeopsTaskProviderResults,
)
from .neops_task_create_mutation import (
    NeopsTaskCreateMutation,
    NeopsTaskCreateMutationNeopsTaskUpsert,
    NeopsTaskCreateMutationNeopsTaskUpsertNeopsTask,
)
from .neops_task_unarchive import (
    NeopsTaskUnarchive,
    NeopsTaskUnarchiveNeopsTaskUpsert,
    NeopsTaskUnarchiveNeopsTaskUpsertNeopsTask,
)
from .neops_tasks import (
    NeopsTasks,
    NeopsTasksNeopsTasks,
    NeopsTasksNeopsTasksResults,
    NeopsTasksNeopsTasksResultsPostRunTasks,
    NeopsTasksNeopsTasksResultsPreRunTasks,
    NeopsTasksNeopsTasksResultsProvider,
)
from .permissions import (
    Permissions,
    PermissionsPermissions,
    PermissionsPermissionsResults,
)
from .platforms import Platforms, PlatformsPlatforms, PlatformsPlatformsResults
from .process_overview import (
    ProcessOverview,
    ProcessOverviewProcessExecutions,
    ProcessOverviewProcessExecutionsResults,
    ProcessOverviewProcessExecutionsResultsExecutions,
    ProcessOverviewProcessExecutionsResultsExecutionsDeviceExecution,
    ProcessOverviewProcessExecutionsResultsExecutionsDeviceExecutionDevice,
    ProcessOverviewProcessExecutionsResultsExecutionsDeviceExecutionDevicePlatform,
    ProcessOverviewProcessExecutionsResultsExecutionsExecutionResults,
    ProcessOverviewProcessExecutionsResultsExecutionsNeopsTask,
    ProcessOverviewProcessExecutionsResultsExecutionsNeopsTaskProvider,
)
from .providers import (
    Providers,
    ProvidersNeopsTaskProvider,
    ProvidersNeopsTaskProviderResults,
)
from .refresh_token import RefreshToken, RefreshTokenRefreshToken
from .reports import (
    Reports,
    ReportsReports,
    ReportsReportsResults,
    ReportsReportsResultsScope,
)
from .reports_execute import (
    ReportsExecute,
    ReportsExecuteReportsExecute,
    ReportsExecuteReportsExecuteReportExecution,
)
from .role_device_group import (
    RoleDeviceGroup,
    RoleDeviceGroupRoleDeviceGroup,
    RoleDeviceGroupRoleDeviceGroupResults,
    RoleDeviceGroupRoleDeviceGroupResultsDeviceGroup,
    RoleDeviceGroupRoleDeviceGroupResultsRole,
)
from .role_device_group_upsert import (
    RoleDeviceGroupUpsert,
    RoleDeviceGroupUpsertRoleDeviceGroupUpsert,
    RoleDeviceGroupUpsertRoleDeviceGroupUpsertRoleDeviceGroup,
)
from .role_neops_task import (
    RoleNeopsTask,
    RoleNeopsTaskRoleNeopsTask,
    RoleNeopsTaskRoleNeopsTaskResults,
    RoleNeopsTaskRoleNeopsTaskResultsNeopsTask,
    RoleNeopsTaskRoleNeopsTaskResultsRole,
)
from .role_neops_task_upsert import (
    RoleNeopsTaskUpsert,
    RoleNeopsTaskUpsertRoleNeopsTaskUpsert,
    RoleNeopsTaskUpsertRoleNeopsTaskUpsertRoleNeopsTask,
)
from .role_permission_element import (
    RolePermissionElement,
    RolePermissionElementRolePermissionElement,
    RolePermissionElementRolePermissionElementResults,
    RolePermissionElementRolePermissionElementResultsPermissionElement,
)
from .role_permission_element_upsert import (
    RolePermissionElementUpsert,
    RolePermissionElementUpsertRolePermissionElementUpsert,
    RolePermissionElementUpsertRolePermissionElementUpsertRolePermissionElement,
)
from .role_permission_upsert import (
    RolePermissionUpsert,
    RolePermissionUpsertRolePermissionUpsert,
    RolePermissionUpsertRolePermissionUpsertRolePermission,
)
from .role_permissions import (
    RolePermissions,
    RolePermissionsRolePermission,
    RolePermissionsRolePermissionResults,
    RolePermissionsRolePermissionResultsDeviceGroupPermissionsAll,
    RolePermissionsRolePermissionResultsDeviceGroupPermissionsAllDeviceGroup,
    RolePermissionsRolePermissionResultsDeviceGroupPermissionsAllRole,
    RolePermissionsRolePermissionResultsNeopsTaskPermissionsAll,
    RolePermissionsRolePermissionResultsNeopsTaskPermissionsAllNeopsTask,
    RolePermissionsRolePermissionResultsNeopsTaskPermissionsAllRole,
    RolePermissionsRolePermissionResultsPermissionElementPermissionsAll,
    RolePermissionsRolePermissionResultsPermissionElementPermissionsAllPermissionElement,
    RolePermissionsRolePermissionResultsPermissionElementPermissionsAllRole,
    RolePermissionsRolePermissionResultsScopePermissionsAll,
    RolePermissionsRolePermissionResultsScopePermissionsAllRole,
    RolePermissionsRolePermissionResultsScopePermissionsAllScope,
    RolePermissionsRolePermissionResultsUsers,
)
from .role_scope_upsert import (
    RoleScopeUpsert,
    RoleScopeUpsertRoleScopeUpsert,
    RoleScopeUpsertRoleScopeUpsertRoleScope,
)
from .role_user import RoleUser, RoleUserRole, RoleUserRoleResults
from .rollback import Rollback, RollbackDeviceRollback, RollbackDeviceRollbackExecution
from .saved_search_create import (
    SavedSearchCreate,
    SavedSearchCreateSavedSearchCreate,
    SavedSearchCreateSavedSearchCreateSavedSearch,
)
from .saved_search_delete import (
    SavedSearchDelete,
    SavedSearchDeleteSavedSearchDelete,
    SavedSearchDeleteSavedSearchDeleteSavedSearch,
)
from .saved_searches import (
    SavedSearches,
    SavedSearchesSavedSearches,
    SavedSearchesSavedSearchesResults,
)
from .scope_delete import (
    ScopeDelete,
    ScopeDeleteScopeDelete,
    ScopeDeleteScopeDeleteScope,
)
from .scopes import Scopes, ScopesScopes, ScopesScopesResults, ScopesScopesResultsTasks
from .scopes_upsert import (
    ScopesUpsert,
    ScopesUpsertScopesUpsert,
    ScopesUpsertScopesUpsertScope,
)
from .single_discovery import (
    SingleDiscovery,
    SingleDiscoveryDiscovery,
    SingleDiscoveryDiscoveryExecution,
)
from .topology import (
    Topology,
    TopologyTopology,
    TopologyTopologyLinks,
    TopologyTopologyLinksProperties,
    TopologyTopologyLinksPropertiesSourceInterface,
    TopologyTopologyLinksPropertiesTargetInterface,
    TopologyTopologyNodes,
    TopologyTopologyNodesProperties,
    TopologyTopologyNodesPropertiesDevice,
)

__all__ = [
    "AbortExecution",
    "AbortExecutionAbortExecution",
    "AbortExecutionAbortExecutionExecutions",
    "AbortExecutionAbortExecutionExecutionsNeopsTask",
    "AddApiKey",
    "AddApiKeyStaticApiKeyCreate",
    "AddRole",
    "AddRoleDeviceGroup",
    "AddRoleDeviceGroupRoleDeviceGroupUpsert",
    "AddRoleDeviceGroupRoleDeviceGroupUpsertRoleDeviceGroup",
    "AddRoleDeviceGroupRoleDeviceGroupUpsertRoleDeviceGroupDeviceGroup",
    "AddRoleDeviceGroupRoleDeviceGroupUpsertRoleDeviceGroupDeviceGroupDevices",
    "AddRoleDeviceGroupRoleDeviceGroupUpsertRoleDeviceGroupRole",
    "AddRoleDeviceGroupRoleDeviceGroupUpsertRoleDeviceGroupRoleUsers",
    "AddRoleNeopsTask",
    "AddRoleNeopsTaskRoleNeopsTaskUpsert",
    "AddRoleNeopsTaskRoleNeopsTaskUpsertRoleNeopsTask",
    "AddRoleNeopsTaskRoleNeopsTaskUpsertRoleNeopsTaskNeopsTask",
    "AddRoleNeopsTaskRoleNeopsTaskUpsertRoleNeopsTaskRole",
    "AddRoleNeopsTaskRoleNeopsTaskUpsertRoleNeopsTaskRoleUsers",
    "AddRoleRoleUpsert",
    "AddRoleRoleUpsertRole",
    "AddRoleRoleUpsertRoleUsers",
    "AddUser",
    "AddUserLocalUserCreate",
    "AddUserLocalUserCreateLocalUser",
    "AddUsersToRole",
    "AddUsersToRoleRoleAddUsers",
    "AddUsersToRoleRoleAddUsersRole",
    "AddUsersToRoleRoleAddUsersRoleUsers",
    "AggregationsType",
    "ArchiveOrDeleteTask",
    "ArchiveOrDeleteTaskNeopsTaskDelete",
    "ArchiveOrDeleteTaskNeopsTaskDeleteNeopsTask",
    "AsyncBaseClient",
    "AutocompleteFields",
    "BaseModel",
    "ChartType",
    "CheckResultEnum",
    "Client",
    "ClientAggregation",
    "ClientAggregationClientAggregation",
    "ClientAggregationClientAggregationResults",
    "Clients",
    "ClientsClientsElastic",
    "ClientsClientsElasticResults",
    "ClientsClientsElasticResultsInterface",
    "ClientsClientsElasticResultsInterfaceDevice",
    "ClientsClientsElasticResultsLocation",
    "ConnectionStateEnum",
    "CronExecuteTypeEnum",
    "CronExecutionType",
    "CronExecutionTypeCronjobExecutionTypes",
    "CronExecutionTypeCronjobExecutionTypesResults",
    "CronJobExecuteTypeEnum",
    "DeviceAggregation",
    "DeviceAggregationDeviceAggregation",
    "DeviceAggregationDeviceAggregationResults",
    "DeviceExecutionStateEnum",
    "DeviceGroupElastic",
    "DeviceGroupElasticGroupsElastic",
    "DeviceGroupElasticGroupsElasticResults",
    "DeviceGroupElasticGroupsElasticResultsLocation",
    "DeviceGroupUpsert",
    "DeviceGroupUpsertDeviceGroupUpsert",
    "DeviceGroupUpsertDeviceGroupUpsertDeviceGroup",
    "DeviceGroupUpsertDeviceGroupUpsertDeviceGroupDevices",
    "DeviceUpsert",
    "DeviceUpsertDeviceUpsert",
    "DeviceUpsertDeviceUpsertDevice",
    "DeviceUpsertDeviceUpsertDeviceGroups",
    "DeviceUpsertDeviceUpsertDevicePlatform",
    "Devices",
    "DevicesDevicesElastic",
    "DevicesDevicesElasticResults",
    "DevicesDevicesElasticResultsGroups",
    "DevicesDevicesElasticResultsPlatform",
    "Discovery",
    "DiscoveryExecute",
    "DiscoveryExecuteExecution",
    "EntityType",
    "ExecuteNeopsTask",
    "ExecuteNeopsTaskExecuteNeopsTask",
    "ExecuteNeopsTaskExecuteNeopsTaskExecutions",
    "ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecution",
    "ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecutionDevice",
    "ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecutionDevicePlatform",
    "ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecutionExecution",
    "ExecuteNeopsTaskExecuteNeopsTaskExecutionsNeopsTask",
    "ExecuteNeopsTaskExecuteNeopsTaskExecutionsNeopsTaskProvider",
    "Execution",
    "ExecutionExecutions",
    "ExecutionExecutionsResults",
    "ExecutionExecutionsResultsDeviceExecution",
    "ExecutionExecutionsResultsDeviceExecutionDevice",
    "ExecutionExecutionsResultsDeviceExecutionDevicePlatform",
    "ExecutionExecutionsResultsExecutionResults",
    "ExecutionExecutionsResultsExecutionResultsClientexecutionresult",
    "ExecutionExecutionsResultsExecutionResultsClientexecutionresultClient",
    "ExecutionExecutionsResultsExecutionResultsDeviceexecutionresult",
    "ExecutionExecutionsResultsExecutionResultsDeviceexecutionresultDevice",
    "ExecutionExecutionsResultsExecutionResultsDevicegroupexecutionresult",
    "ExecutionExecutionsResultsExecutionResultsDevicegroupexecutionresultGroup",
    "ExecutionExecutionsResultsExecutionResultsInterfaceexecutionresult",
    "ExecutionExecutionsResultsExecutionResultsInterfaceexecutionresultInterface",
    "ExecutionExecutionsResultsNeopsTask",
    "ExecutionExecutionsResultsNeopsTaskProvider",
    "ExecutionExecutionsResultsProcess",
    "ExecutionResultStateEnum",
    "ExecutionStateEnum",
    "ExecutionSubscription",
    "ExecutionSubscriptionExecutionSubscription",
    "ExecutionSubscriptionExecutionSubscriptionExecution",
    "ExecutionSubscriptionExecutionSubscriptionExecutionNeopsTask",
    "ExecutionSubscriptionExecutionSubscriptionExecutionNeopsTaskProvider",
    "ExecutionSubscriptionExecutionSubscriptionExecutionProcess",
    "ExecutionTypeEnum",
    "ExecutionsDetail",
    "ExecutionsDetailExecutions",
    "ExecutionsDetailExecutionsResults",
    "ExecutionsDetailExecutionsResultsExecutionResults",
    "ExecutionsDetailExecutionsResultsExecutionResultsClientexecutionresult",
    "ExecutionsDetailExecutionsResultsExecutionResultsClientexecutionresultClient",
    "ExecutionsDetailExecutionsResultsExecutionResultsDeviceexecutionresult",
    "ExecutionsDetailExecutionsResultsExecutionResultsDeviceexecutionresultDevice",
    "ExecutionsDetailExecutionsResultsExecutionResultsDevicegroupexecutionresult",
    "ExecutionsDetailExecutionsResultsExecutionResultsDevicegroupexecutionresultGroup",
    "ExecutionsDetailExecutionsResultsExecutionResultsInterfaceexecutionresult",
    "ExecutionsDetailExecutionsResultsExecutionResultsInterfaceexecutionresultInterface",
    "ExecutionsDetailExecutionsResultsNeopsTask",
    "ExecutionsDetailExecutionsResultsNeopsTaskProvider",
    "ExecutionsDetailExecutionsResultsProcess",
    "ExecutionsDetailExecutionsResultsUser",
    "ExecutionsElastic",
    "ExecutionsElasticExecutionsElastic",
    "ExecutionsElasticExecutionsElasticResults",
    "ExecutionsElasticExecutionsElasticResultsNeopsTask",
    "ExecutionsElasticExecutionsElasticResultsNeopsTaskProvider",
    "ExecutionsElasticExecutionsElasticResultsProcess",
    "ExecutionsElasticExecutionsElasticResultsUser",
    "ExecutionsSimple",
    "ExecutionsSimpleExecutions",
    "ExecutionsSimpleExecutionsResults",
    "ExecutionsSimpleExecutionsResultsNeopsTask",
    "ExecutionsSimpleExecutionsResultsNeopsTaskProvider",
    "ExecutionsSimpleExecutionsResultsProcess",
    "ExecutionsSimpleExecutionsResultsUser",
    "GetRole",
    "GetRoleRole",
    "GetRoleRoleResults",
    "GraphQLClientError",
    "GraphQLClientGraphQLError",
    "GraphQLClientGraphQLMultiError",
    "GraphQLClientHttpError",
    "GraphQLClientInvalidResponseError",
    "GroupAggregation",
    "GroupAggregationGroupAggregation",
    "GroupAggregationGroupAggregationResults",
    "IndexesEnum",
    "InterfaceAggregation",
    "InterfaceAggregationInterfaceAggregation",
    "InterfaceAggregationInterfaceAggregationResults",
    "InterfaceStateEnum",
    "Interfaces",
    "InterfacesInterfacesElastic",
    "InterfacesInterfacesElasticResults",
    "InterfacesInterfacesElasticResultsDevice",
    "InterfacesInterfacesElasticResultsInterface",
    "JsonForm",
    "JsonFormJsonForm",
    "JsonFormJsonFormClients",
    "JsonFormJsonFormDevices",
    "JsonFormJsonFormGroups",
    "JsonFormJsonFormInterfaces",
    "JsonFormJsonFormInterfacesDevice",
    "LocationUpsert",
    "LocationUpsertLocationUpsert",
    "LocationUpsertLocationUpsertLocation",
    "LocationUpsertLocationUpsertLocationDevices",
    "Login",
    "LoginLogin",
    "LoginLoginUser",
    "NeopsProvider",
    "NeopsProviderNeopsTaskProvider",
    "NeopsProviderNeopsTaskProviderResults",
    "NeopsTaskCreateMutation",
    "NeopsTaskCreateMutationNeopsTaskUpsert",
    "NeopsTaskCreateMutationNeopsTaskUpsertNeopsTask",
    "NeopsTaskCronJobExecuteTypeEnum",
    "NeopsTaskUnarchive",
    "NeopsTaskUnarchiveNeopsTaskUpsert",
    "NeopsTaskUnarchiveNeopsTaskUpsertNeopsTask",
    "NeopsTask_ProviderTypeEnum",
    "NeopsTask_RunOnEnum",
    "NeopsTask_RunOnStrictEnum",
    "NeopsTask_ValidityStateEnum",
    "NeopsTasks",
    "NeopsTasksNeopsTasks",
    "NeopsTasksNeopsTasksResults",
    "NeopsTasksNeopsTasksResultsPostRunTasks",
    "NeopsTasksNeopsTasksResultsPreRunTasks",
    "NeopsTasksNeopsTasksResultsProvider",
    "OutputSchemaTypeEnum",
    "Permissions",
    "PermissionsPermissions",
    "PermissionsPermissionsResults",
    "Platforms",
    "PlatformsPlatforms",
    "PlatformsPlatformsResults",
    "ProcessOverview",
    "ProcessOverviewProcessExecutions",
    "ProcessOverviewProcessExecutionsResults",
    "ProcessOverviewProcessExecutionsResultsExecutions",
    "ProcessOverviewProcessExecutionsResultsExecutionsDeviceExecution",
    "ProcessOverviewProcessExecutionsResultsExecutionsDeviceExecutionDevice",
    "ProcessOverviewProcessExecutionsResultsExecutionsDeviceExecutionDevicePlatform",
    "ProcessOverviewProcessExecutionsResultsExecutionsExecutionResults",
    "ProcessOverviewProcessExecutionsResultsExecutionsNeopsTask",
    "ProcessOverviewProcessExecutionsResultsExecutionsNeopsTaskProvider",
    "ProviderSchemaEnum",
    "ProviderTypeEnum",
    "Providers",
    "ProvidersNeopsTaskProvider",
    "ProvidersNeopsTaskProviderResults",
    "RefreshToken",
    "RefreshTokenRefreshToken",
    "RegexTypeEnum",
    "Reports",
    "ReportsExecute",
    "ReportsExecuteReportsExecute",
    "ReportsExecuteReportsExecuteReportExecution",
    "ReportsReports",
    "ReportsReportsResults",
    "ReportsReportsResultsScope",
    "RoleDeviceGroup",
    "RoleDeviceGroupRoleDeviceGroup",
    "RoleDeviceGroupRoleDeviceGroupResults",
    "RoleDeviceGroupRoleDeviceGroupResultsDeviceGroup",
    "RoleDeviceGroupRoleDeviceGroupResultsRole",
    "RoleDeviceGroupUpsert",
    "RoleDeviceGroupUpsertRoleDeviceGroupUpsert",
    "RoleDeviceGroupUpsertRoleDeviceGroupUpsertRoleDeviceGroup",
    "RoleNeopsTask",
    "RoleNeopsTaskRoleNeopsTask",
    "RoleNeopsTaskRoleNeopsTaskResults",
    "RoleNeopsTaskRoleNeopsTaskResultsNeopsTask",
    "RoleNeopsTaskRoleNeopsTaskResultsRole",
    "RoleNeopsTaskUpsert",
    "RoleNeopsTaskUpsertRoleNeopsTaskUpsert",
    "RoleNeopsTaskUpsertRoleNeopsTaskUpsertRoleNeopsTask",
    "RolePermissionElement",
    "RolePermissionElementRolePermissionElement",
    "RolePermissionElementRolePermissionElementResults",
    "RolePermissionElementRolePermissionElementResultsPermissionElement",
    "RolePermissionElementUpsert",
    "RolePermissionElementUpsertRolePermissionElementUpsert",
    "RolePermissionElementUpsertRolePermissionElementUpsertRolePermissionElement",
    "RolePermissionUpsert",
    "RolePermissionUpsertRolePermissionUpsert",
    "RolePermissionUpsertRolePermissionUpsertRolePermission",
    "RolePermissions",
    "RolePermissionsRolePermission",
    "RolePermissionsRolePermissionResults",
    "RolePermissionsRolePermissionResultsDeviceGroupPermissionsAll",
    "RolePermissionsRolePermissionResultsDeviceGroupPermissionsAllDeviceGroup",
    "RolePermissionsRolePermissionResultsDeviceGroupPermissionsAllRole",
    "RolePermissionsRolePermissionResultsNeopsTaskPermissionsAll",
    "RolePermissionsRolePermissionResultsNeopsTaskPermissionsAllNeopsTask",
    "RolePermissionsRolePermissionResultsNeopsTaskPermissionsAllRole",
    "RolePermissionsRolePermissionResultsPermissionElementPermissionsAll",
    "RolePermissionsRolePermissionResultsPermissionElementPermissionsAllPermissionElement",
    "RolePermissionsRolePermissionResultsPermissionElementPermissionsAllRole",
    "RolePermissionsRolePermissionResultsScopePermissionsAll",
    "RolePermissionsRolePermissionResultsScopePermissionsAllRole",
    "RolePermissionsRolePermissionResultsScopePermissionsAllScope",
    "RolePermissionsRolePermissionResultsUsers",
    "RoleScopeUpsert",
    "RoleScopeUpsertRoleScopeUpsert",
    "RoleScopeUpsertRoleScopeUpsertRoleScope",
    "RoleUser",
    "RoleUserRole",
    "RoleUserRoleResults",
    "Rollback",
    "RollbackDeviceRollback",
    "RollbackDeviceRollbackExecution",
    "RunOnEnum",
    "SavedSearchCreate",
    "SavedSearchCreateSavedSearchCreate",
    "SavedSearchCreateSavedSearchCreateSavedSearch",
    "SavedSearchDelete",
    "SavedSearchDeleteSavedSearchDelete",
    "SavedSearchDeleteSavedSearchDeleteSavedSearch",
    "SavedSearches",
    "SavedSearchesSavedSearches",
    "SavedSearchesSavedSearchesResults",
    "ScopeDelete",
    "ScopeDeleteScopeDelete",
    "ScopeDeleteScopeDeleteScope",
    "Scopes",
    "ScopesScopes",
    "ScopesScopesResults",
    "ScopesScopesResultsTasks",
    "ScopesUpsert",
    "ScopesUpsertScopesUpsert",
    "ScopesUpsertScopesUpsertScope",
    "SingleDiscovery",
    "SingleDiscoveryDiscovery",
    "SingleDiscoveryDiscoveryExecution",
    "Topology",
    "TopologyTopology",
    "TopologyTopologyLinks",
    "TopologyTopologyLinksProperties",
    "TopologyTopologyLinksPropertiesSourceInterface",
    "TopologyTopologyLinksPropertiesTargetInterface",
    "TopologyTopologyNodes",
    "TopologyTopologyNodesProperties",
    "TopologyTopologyNodesPropertiesDevice",
    "Upload",
]
