# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class Login(BaseModel):
    login: Optional["LoginLogin"]


class LoginLogin(BaseModel):
    access_token: Optional[str] = Field(alias="accessToken")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    roles: Optional[List[Optional[str]]]
    user: Optional["LoginLoginUser"]


class LoginLoginUser(BaseModel):
    id: str
    email: Optional[str]
    username: Optional[str]


Login.model_rebuild()
LoginLogin.model_rebuild()
