# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class SavedSearches(BaseModel):
    saved_searches: Optional["SavedSearchesSavedSearches"] = Field(
        alias="savedSearches"
    )


class SavedSearchesSavedSearches(BaseModel):
    results: Optional[List[Optional["SavedSearchesSavedSearchesResults"]]]


class SavedSearchesSavedSearchesResults(BaseModel):
    id: str
    name: Optional[str]
    description: Optional[str]
    search: Optional[str]


SavedSearches.model_rebuild()
SavedSearchesSavedSearches.model_rebuild()
