# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class SavedSearchCreate(BaseModel):
    saved_search_create: Optional["SavedSearchCreateSavedSearchCreate"] = Field(
        alias="savedSearchCreate"
    )


class SavedSearchCreateSavedSearchCreate(BaseModel):
    saved_search: Optional["SavedSearchCreateSavedSearchCreateSavedSearch"] = Field(
        alias="savedSearch"
    )


class SavedSearchCreateSavedSearchCreateSavedSearch(BaseModel):
    id: str
    name: Optional[str]
    description: Optional[str]
    search: Optional[str]


SavedSearchCreate.model_rebuild()
SavedSearchCreateSavedSearchCreate.model_rebuild()
