# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class RefreshToken(BaseModel):
    refresh_token: Optional["RefreshTokenRefreshToken"] = Field(alias="refreshToken")


class RefreshTokenRefreshToken(BaseModel):
    access_token: Optional[str] = Field(alias="accessToken")
    refresh_token: Optional[str] = Field(alias="refreshToken")


RefreshToken.model_rebuild()
