# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class ClientAggregation(BaseModel):
    client_aggregation: Optional["ClientAggregationClientAggregation"] = Field(
        alias="clientAggregation"
    )


class ClientAggregationClientAggregation(BaseModel):
    results: Optional[List[Optional["ClientAggregationClientAggregationResults"]]]
    count_aggregated_elements: Optional[int] = Field(alias="countAggregatedElements")
    count: Optional[int]


class ClientAggregationClientAggregationResults(BaseModel):
    value: Optional[str]
    count: Optional[int]


ClientAggregation.model_rebuild()
ClientAggregationClientAggregation.model_rebuild()
