# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GroupAggregation(BaseModel):
    group_aggregation: Optional["GroupAggregationGroupAggregation"] = Field(
        alias="groupAggregation"
    )


class GroupAggregationGroupAggregation(BaseModel):
    results: Optional[List[Optional["GroupAggregationGroupAggregationResults"]]]
    count_aggregated_elements: Optional[int] = Field(alias="countAggregatedElements")
    count: Optional[int]


class GroupAggregationGroupAggregationResults(BaseModel):
    value: Optional[str]
    count: Optional[int]


GroupAggregation.model_rebuild()
GroupAggregationGroupAggregation.model_rebuild()
