# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class ArchiveOrDeleteTask(BaseModel):
    neops_task_delete: Optional["ArchiveOrDeleteTaskNeopsTaskDelete"] = Field(
        alias="neopsTaskDelete"
    )


class ArchiveOrDeleteTaskNeopsTaskDelete(BaseModel):
    neops_task: Optional["ArchiveOrDeleteTaskNeopsTaskDeleteNeopsTask"] = Field(
        alias="neopsTask"
    )


class ArchiveOrDeleteTaskNeopsTaskDeleteNeopsTask(BaseModel):
    id: str


ArchiveOrDeleteTask.model_rebuild()
ArchiveOrDeleteTaskNeopsTaskDelete.model_rebuild()
