# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class ScopesUpsert(BaseModel):
    scopes_upsert: Optional["ScopesUpsertScopesUpsert"] = Field(alias="scopesUpsert")


class ScopesUpsertScopesUpsert(BaseModel):
    scope: Optional["ScopesUpsertScopesUpsertScope"]


class ScopesUpsertScopesUpsertScope(BaseModel):
    id: str
    name: Optional[str]


ScopesUpsert.model_rebuild()
ScopesUpsertScopesUpsert.model_rebuild()
