# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class RoleScopeUpsert(BaseModel):
    role_scope_upsert: Optional["RoleScopeUpsertRoleScopeUpsert"] = Field(
        alias="roleScopeUpsert"
    )


class RoleScopeUpsertRoleScopeUpsert(BaseModel):
    role_scope: Optional["RoleScopeUpsertRoleScopeUpsertRoleScope"] = Field(
        alias="roleScope"
    )


class RoleScopeUpsertRoleScopeUpsertRoleScope(BaseModel):
    id: str
    permission_flags: Optional[List[Optional[str]]] = Field(alias="permissionFlags")


RoleScopeUpsert.model_rebuild()
RoleScopeUpsertRoleScopeUpsert.model_rebuild()
