# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class SavedSearchDelete(BaseModel):
    saved_search_delete: Optional["SavedSearchDeleteSavedSearchDelete"] = Field(
        alias="savedSearchDelete"
    )


class SavedSearchDeleteSavedSearchDelete(BaseModel):
    saved_search: Optional["SavedSearchDeleteSavedSearchDeleteSavedSearch"] = Field(
        alias="savedSearch"
    )


class SavedSearchDeleteSavedSearchDeleteSavedSearch(BaseModel):
    id: str


SavedSearchDelete.model_rebuild()
SavedSearchDeleteSavedSearchDelete.model_rebuild()
